BearerTokenAuthorizationPolicy

Struct BearerTokenAuthorizationPolicy 

pub struct BearerTokenAuthorizationPolicy { /* private fields */ }
Authentication policy for a bearer token.

Implementations

Source

impl BearerTokenAuthorizationPolicy

pub fn new<A, B>(credential: Arc<dyn TokenCredential>, scopes: A) -> Self
where A: IntoIterator<Item = B>, B: Into<String>,

Creates a new BearerTokenAuthorizationPolicy.

pub fn with_on_request(self, on_request: Arc<dyn OnRequest>) -> Self

Sets a callback for send to invoke once on each request it receives, before sending the request.

See OnRequest for more details. When not set, the policy authorizes each request using the credential and scopes specified to new.

pub fn with_on_challenge(self, on_challenge: Arc<dyn OnChallenge>) -> Self

Sets a callback to invoke upon receiving a 401 Unauthorized response with an authentication challenge.

See OnChallenge for more details. When not set, send returns 401 responses without attempting to handle their challenges.