Authorizer

Trait Authorizer 

pub trait Authorizer:
    Sealed
    + Debug
    + Send
    + Sync {
    // Required method
    fn authorize<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
        &'life0 self,
        request: &'life1 mut Request,
        scopes: &'life2 [&'life3 str],
        options: TokenRequestOptions<'life4>,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait,
             'life4: 'async_trait;
}
Helper trait used by OnChallenge and OnRequest to authorize requests. This trait is sealed and cannot be implemented outside of this module.

Required Methods

fn authorize<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>( &'life0 self, request: &'life1 mut Request, scopes: &'life2 [&'life3 str], options: TokenRequestOptions<'life4>, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait, 'life4: 'async_trait,

Acquire an access token for the provided scopes and options, and set the request’s authorization header.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors