pub struct BearerTokenAuthorizationPolicy { /* private fields */ }Expand description
Authentication policy for a bearer token.
Implementations
Sourceimpl BearerTokenAuthorizationPolicy
impl BearerTokenAuthorizationPolicy
Sourcepub fn new<A, B>(credential: Arc<dyn TokenCredential>, scopes: A) -> Self
pub fn new<A, B>(credential: Arc<dyn TokenCredential>, scopes: A) -> Self
Creates a new BearerTokenAuthorizationPolicy.
Sourcepub fn with_on_request(self, on_request: Arc<dyn OnRequest>) -> Self
pub fn with_on_request(self, on_request: Arc<dyn OnRequest>) -> Self
Sets a callback for send to invoke once on each request it receives, before sending the request.
See OnRequest for more details. When not set, the policy authorizes each request using the credential
and scopes specified to new.
Sourcepub fn with_on_challenge(self, on_challenge: Arc<dyn OnChallenge>) -> Self
pub fn with_on_challenge(self, on_challenge: Arc<dyn OnChallenge>) -> Self
Sets a callback to invoke upon receiving a 401 Unauthorized response with an authentication challenge.
See OnChallenge for more details. When not set, send returns 401 responses without attempting to
handle their challenges.